@@ -3,14 +3,15 @@
 
 // Constants
 
-const int max_speed = 2300;
-const double jump_max_duration = 0.2;
-const double jump_speed = 291 + (2/3);
-const double jump_acc = 1458 + (1/3);
+static const int max_speed = 2300;
+static const double jump_max_duration = 0.2;
+static const double jump_speed = 291 + (2 / 3);
+static const double jump_acc = 1458 + (1 / 3);
 
 // Vector stuff
 
-double cap(double value, double min, double max) {
+double cap(double value, double min, double max)
+{
     if (value < min)
         return min;
     if (value > max)
@@ -18,99 +19,105 @@ double cap(double value, double min, double max) {
     return value;
 };
 
-typedef struct vector {
+typedef struct vector
+{
     double x;
     double y;
     double z;
 } Vector;
 
-struct opti_norm {
+struct opti_norm
+{
     Vector vector;
     double magnitude;
 };
 
-Vector add(Vector vec1, Vector vec2) {
-    return (Vector) {
-        .x=vec1.x + vec2.x, .y=vec1.y + vec2.y, .z=vec1.z + vec2.z
-    };
+Vector add(Vector vec1, Vector vec2)
+{
+    return (Vector){
+        .x = vec1.x + vec2.x, .y = vec1.y + vec2.y, .z = vec1.z + vec2.z};
 };
 
-Vector sub(Vector vec1, Vector vec2) {
-    return (Vector) {
-        .x=vec1.x - vec2.x, .y=vec1.y - vec2.y, .z=vec1.z - vec2.z
-    };
+Vector sub(Vector vec1, Vector vec2)
+{
+    return (Vector){
+        .x = vec1.x - vec2.x, .y = vec1.y - vec2.y, .z = vec1.z - vec2.z};
 };
 
-Vector multiply(Vector vec1, Vector vec2) {
-    return (Vector) {
-        .x=vec1.x * vec2.x, .y=vec1.y * vec2.y, .z=vec1.z * vec2.z
-    };
+Vector multiply(Vector vec1, Vector vec2)
+{
+    return (Vector){
+        .x = vec1.x * vec2.x, .y = vec1.y * vec2.y, .z = vec1.z * vec2.z};
 };
 
-Vector divide(Vector vec1, Vector vec2) {
-    return (Vector) {
-        .x=vec1.x / vec2.x, .y=vec1.y / vec2.y, .z=vec1.z / vec2.z
-    };
+Vector divide(Vector vec1, Vector vec2)
+{
+    return (Vector){
+        .x = vec1.x / vec2.x, .y = vec1.y / vec2.y, .z = vec1.z / vec2.z};
 };
 
-double dot(Vector vec1, Vector vec2) {
+double dot(Vector vec1, Vector vec2)
+{
     return vec1.x * vec2.x + vec1.y * vec2.y + vec1.z * vec2.z;
 };
 
-double magnitude(Vector vec) {
+double magnitude(Vector vec)
+{
     return sqrt(dot(vec, vec));
 };
 
-struct opti_norm normalize(Vector vec) {
+struct opti_norm normalize(Vector vec)
+{
     struct opti_norm r;
     r.vector = (Vector){
-        .x=0, .y=0, .z=0
-    };
+        .x = 0, .y = 0, .z = 0};
     r.magnitude = magnitude(vec);
 
-    if (r.magnitude != 0) {
+    if (r.magnitude != 0)
+    {
         r.vector = (Vector){
-            .x=vec.x/r.magnitude, .y=vec.y/r.magnitude, .z=vec.z/r.magnitude
-        };
+            .x = vec.x / r.magnitude, .y = vec.y / r.magnitude, .z = vec.z / r.magnitude};
     }
 
     return r;
 };
 
-Vector flatten(Vector vec) {
-    return (Vector) {
-        .x=vec.x, .y=vec.y, .z=0
-    };
+Vector flatten(Vector vec)
+{
+    return (Vector){
+        .x = vec.x, .y = vec.y, .z = 0};
 }
 
-double angle(Vector vec1, Vector vec2) {
+double angle(Vector vec1, Vector vec2)
+{
     return acos(cap(dot(normalize(vec1).vector, normalize(vec2).vector), -1, 1));
 };
 
-Vector cross(Vector vec1, Vector vec2) {
-    return (Vector) {
-        .x=(vec1.y * vec2.z) - (vec1.z * vec2.y), .y=(vec1.z * vec2.x) - (vec1.x * vec2.z), .z=(vec1.x * vec2.y) - (vec1.y * vec2.x)
-    };
+Vector cross(Vector vec1, Vector vec2)
+{
+    return (Vector){
+        .x = (vec1.y * vec2.z) - (vec1.z * vec2.y), .y = (vec1.z * vec2.x) - (vec1.x * vec2.z), .z = (vec1.x * vec2.y) - (vec1.y * vec2.x)};
 };
 
-Vector double_to_vector(double num) {
-    return (Vector) {
-        .x=num, .y=num, .z=num
-    };
+Vector double_to_vector(double num)
+{
+    return (Vector){
+        .x = num, .y = num, .z = num};
 }
 
-Vector clamp(Vector vec, Vector start, Vector end) {
+Vector clamp(Vector vec, Vector start, Vector end)
+{
     Vector s = normalize(vec).vector;
-    _Bool right = dot(s, cross(end, (Vector) {
-        .x=0, .y=0, .z=-1
-    })) < 0;
-    _Bool left = dot(s, cross(start, (Vector) {
-        .x=0, .y=0, .z=-1
-    })) > 0;
+    _Bool right = dot(s, cross(end, (Vector){
+                                        .x = 0, .y = 0, .z = -1})) < 0;
+    _Bool left = dot(s, cross(start, (Vector){
+                                         .x = 0, .y = 0, .z = -1})) > 0;
 
-    if ((dot(end, cross(start, (Vector) {
-        .x=0, .y=0, .z=-1
-    })) > 0) ? (right && left) : (right || left)) {
+    if ((dot(end, cross(start, (Vector){
+                                   .x = 0, .y = 0, .z = -1})) > 0)
+            ? (right && left)
+            : (right || left))
+    {
         return vec;
     }
 
@@ -120,65 +127,64 @@ Vector clamp(Vector vec, Vector start, Vector end) {
     return start;
 }
 
-double distance(Vector vec1, Vector vec2) {
+double distance(Vector vec1, Vector vec2)
+{
     return magnitude(sub(vec1, vec2));
 };
 
 // Main lib
 
-struct jump_shot {
+struct jump_shot
+{
     int found;
     Vector best_shot_vector;
-    int direction;
 };
 
-struct aerial_shot {
+struct aerial_shot
+{
     int found;
     Vector ball_intercept;
 };
 
-struct post_correction {
+struct post_correction
+{
     Vector left;
     Vector right;
     _Bool swapped;
 };
 
-struct post_correction correct_for_posts(Vector ball_location, Vector left_target, Vector right_target) {
+struct post_correction correct_for_posts(Vector ball_location, Vector left_target, Vector right_target)
+{
     double ball_radius = 120;
-    Vector goal_line_perp = cross(sub(right_target, left_target), (Vector) {
-        .x=0, .y=0, .z=1
-    });
-    Vector left = add(left_target, cross(normalize(sub(left_target, ball_location)).vector, multiply((Vector) {
-        .x=0, .y=0, .z=1
-    }, double_to_vector(ball_radius))));
-    Vector right = add(right_target, cross(normalize(sub(right_target, ball_location)).vector, multiply((Vector) {
-        .x=0, .y=0, .z=1
-    }, double_to_vector(ball_radius))));
+    Vector goal_line_perp = cross(sub(right_target, left_target), (Vector){0, 0, 1});
+    Vector left = add(left_target, cross(normalize(sub(left_target, ball_location)).vector, multiply((Vector){0, 0, 1}, double_to_vector(ball_radius))));
+    Vector right = add(right_target, cross(normalize(sub(right_target, ball_location)).vector, multiply((Vector){0, 0, 1}, double_to_vector(ball_radius))));
 
     struct post_correction r;
     r.left = (dot(sub(left, left_target), goal_line_perp) > 0) ? left_target : left;
     r.right = (dot(sub(right, right_target), goal_line_perp) > 0) ? right_target : right;
-    r.swapped = dot(cross(normalize(sub(left, ball_location)).vector, (Vector) {
-        .x=0, .y=0, .z=1
-    }), normalize(sub(right, ball_location)).vector) > -0.1;
+    r.swapped = dot(cross(normalize(sub(left, ball_location)).vector, (Vector){0, 0, 1}), normalize(sub(right, ball_location)).vector) > -0.1;
 
     return r;
 };
 
-_Bool in_field(Vector point, int radius) {
-    point = (Vector){ .x=fabs(point.x), .y=fabs(point.y), .z=fabs(point.z) };
+_Bool in_field(Vector point, int radius)
+{
+    point = (Vector){.x = fabs(point.x), .y = fabs(point.y), .z = fabs(point.z)};
     return !((point.x > 4080 - radius) || (point.y > 5900 - radius) || (point.x > 880 - radius && point.y > 5105 - radius) || (point.x > 2650 && point.y > -point.x + 8025 - radius));
 };
 
-_Bool fast_shot(Vector car_location, Vector ball_intercept, double time_remaining, double cap_, int speed) {
+_Bool fast_shot(Vector car_location, Vector ball_intercept, double time_remaining, double cap_, int speed)
+{
     return time_remaining <= min(cap_, distance(car_location, ball_intercept) / speed);
 }
 
-double find_slope(Vector shot_vector, Vector car_to_target) {
+double find_slope(Vector shot_vector, Vector car_to_target)
+{
     double d = dot(shot_vector, car_to_target);
-    double e = fabs(dot(cross(shot_vector, (Vector) {
-        .x=0, .y=0, .z=1
-    }), car_to_target));
+    double e = fabs(dot(cross(shot_vector, (Vector){
+                                               0, 0, 1}),
+                        car_to_target));
 
     if (e == 0)
         return 10 * copysign(1, d);
@@ -186,7 +192,8 @@ double find_slope(Vector shot_vector, Vector car_to_target) {
     return max(min(d / e, 3), -3);
 };
 
-struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double cap_) {
+struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, Vector left_target, Vector right_target, double cap_)
+{
     struct jump_shot r;
     r.found = -1;
 
@@ -201,28 +208,23 @@ struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, do
     double forward_time = time_remaining - (forward_angle * 0.318);
     double backward_time = time_remaining - (backward_angle * 0.418);
 
-    double forward_flag = forward_time > 0 && (distance*1.05 / forward_time) < ((car_boost > distance/100) ? 2275 : 1400);
-    double backward_flag = distance < 1500 && backward_time > 0 && (distance*1.05 / backward_time) < 1200;
+    _Bool forward_flag = forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400);
+    _Bool backward_flag = backward_time > 0 && distance < 1500 && (distance * 1.05 / backward_time) < 1200;
 
-    if (forward_flag || backward_flag) {
+    if (forward_flag || backward_flag)
+    {
         struct post_correction pst_crrctn = correct_for_posts(ball_location, left_target, right_target);
-        if (!pst_crrctn.swapped) {
+        if (!pst_crrctn.swapped)
+        {
             Vector left_vector = normalize(sub(pst_crrctn.left, ball_location)).vector;
             Vector right_vector = normalize(sub(pst_crrctn.right, ball_location)).vector;
             r.best_shot_vector = clamp(direction, left_vector, right_vector);
 
-            if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && fast_shot(car_location, ball_location, time_remaining, cap_, 250)) {
+            if (in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1) && fast_shot(car_location, ball_location, time_remaining, cap_, 250))
+            {
                 double slope = find_slope(r.best_shot_vector, car_to_ball);
-                if (forward_flag && ball_location.z <= 275 && slope > 0) {
+                if ((forward_flag && ball_location.z <= 300 && slope > 0) || (backward_flag && ball_location.z < 250 && slope > 0.5 && time_remaining < cap_ / 2))
                     r.found = 1;
-                    r.direction = 1;
-                    return r;
-                }
-                else if (backward_flag && ball_location.z < 250 && slope > 1.5 && time_remaining < cap_/2) {
-                    r.found = 1;
-                    r.direction = -1;
-                    return r;
-                }
             }
         }
     }
@@ -230,7 +232,8 @@ struct jump_shot parse_slice_for_jump_shot_with_target(double time_remaining, do
     return r;
 };
 
-struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double cap_) {
+struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_shot_value, Vector ball_location, Vector car_location, Vector car_forward, int car_boost, double cap_)
+{
     struct jump_shot r;
     r.found = -1;
 
@@ -245,27 +248,23 @@ struct jump_shot parse_slice_for_jump_shot(double time_remaining, double best_sh
     double forward_time = time_remaining - (forward_angle * 0.318);
     double backward_time = time_remaining - (backward_angle * 0.418);
 
-    double forward_flag = forward_time > 0 && (distance / forward_time) < ((car_boost > distance/100) ? 2275 : 1400);
-    double backward_flag = distance < 1500 && backward_time > 0 && (distance*1.05 / backward_time) < 1200;
+    _Bool forward_flag = forward_time > 0 && (distance / forward_time) < ((car_boost > distance / 100) ? 2275 : 1400);
+    _Bool backward_flag = backward_time > 0 && (distance * 1.05 / backward_time) < 1200;
 
     r.best_shot_vector = direction;
 
-    if ((forward_flag || backward_flag) && in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1)) {
+    if ((forward_flag || backward_flag) && in_field(sub(ball_location, multiply(r.best_shot_vector, double_to_vector(best_shot_value))), 1))
+    {
         double slope = find_slope(r.best_shot_vector, car_to_ball);
-        if (forward_flag && ball_location.z <= 275 && slope > 0) {
+        if ((forward_flag && ball_location.z <= 300 && slope > 0) || (backward_flag && ball_location.z < 250 && slope > 0.5 && time_remaining < cap_ / 2))
             r.found = 1;
-            r.direction = 1;
-        }
-        else if (backward_flag && ball_location.z < 250 && slope > 1.5 && time_remaining < cap_/2) {
-            r.found = 1;
-            r.direction = -1;
-        }
     }
 
     return r;
 };
 
-struct car {
+struct car
+{
     Vector location;
     Vector velocity;
     Vector up;
@@ -274,16 +273,23 @@ struct car {
     int boost;
 };
 
-_Bool is_viable(double time_remaining, double boost_accel, Vector gravity, struct car me, Vector target) {
+_Bool is_viable(double time_remaining, double hitbox_height, double boost_accel, Vector gravity, struct car me, Vector target)
+{
     Vector T = double_to_vector(time_remaining);
     Vector xf = add(add(me.location, multiply(me.velocity, T)), multiply(multiply(multiply(double_to_vector(0.5), gravity), T), T));
     Vector vf = add(me.velocity, multiply(gravity, T));
 
-    if (me.airborne == -1) {
+    _Bool ceiling = me.location.z > 2044 - hitbox_height;
+
+    if (me.airborne == -1 && !ceiling)
+    {
         xf = add(xf, multiply(me.up, double_to_vector(jump_speed * (2 * time_remaining - jump_max_duration) + jump_acc * (time_remaining * jump_max_duration - 0.5 * jump_max_duration * jump_max_duration))));
         vf = add(vf, multiply(me.up, double_to_vector(2 * jump_speed + jump_acc * jump_max_duration)));
     }
 
+    if (ceiling)
+        target.z -= 92;
+
     Vector delta_x = sub(target, xf);
     Vector f = normalize(delta_x).vector;
 
@@ -304,7 +310,8 @@ _Bool is_viable(double time_remaining, double boost_accel, Vector gravity, struc
     return enough_speed && enough_boost && enough_time;
 };
 
-struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, Vector left_target, Vector right_target, double cap_) {
+struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, Vector left_target, Vector right_target, double cap_)
+{
     struct aerial_shot r;
     r.found = -1;
 
@@ -312,15 +319,17 @@ struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining
     Vector direction = normalize(car_to_ball).vector;
 
     struct post_correction pst_crrctn = correct_for_posts(ball_location, left_target, right_target);
-    if (!pst_crrctn.swapped) {
+    if (!pst_crrctn.swapped)
+    {
         Vector left_vector = normalize(sub(pst_crrctn.left, ball_location)).vector;
         Vector right_vector = normalize(sub(pst_crrctn.right, ball_location)).vector;
         r.ball_intercept = sub(ball_location, multiply(clamp(direction, left_vector, right_vector), double_to_vector(best_shot_value)));
 
-        if (in_field(r.ball_intercept, 1) && fast_shot(me.location, ball_location, time_remaining, cap_, 250)) {
+        if (in_field(r.ball_intercept, 1) && fast_shot(me.location, ball_location, time_remaining, cap_, 250))
+        {
             double slope = find_slope(r.ball_intercept, car_to_ball);
 
-            if (slope > 0 && is_viable(time_remaining, boost_accel, gravity, me, r.ball_intercept))
+            if (slope > 0 && is_viable(time_remaining, ceil(best_shot_value - 92.75) * 2, boost_accel, gravity, me, r.ball_intercept))
                 r.found = 1;
         }
     }
@@ -328,50 +337,55 @@ struct aerial_shot parse_slice_for_aerial_shot_with_target(double time_remaining
     return r;
 };
 
-struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, double cap_) {
+struct aerial_shot parse_slice_for_aerial_shot(double time_remaining, double best_shot_value, double boost_accel, Vector gravity, Vector ball_location, struct car me, double cap_)
+{
     struct aerial_shot r;
     r.found = -1;
 
     Vector car_to_ball = sub(ball_location, me.location);
     r.ball_intercept = sub(ball_location, multiply(normalize(car_to_ball).vector, double_to_vector(best_shot_value)));
 
-    if (in_field(r.ball_intercept, 1)) {
+    if (in_field(r.ball_intercept, 1))
+    {
         double slope = find_slope(r.ball_intercept, car_to_ball);
 
-        if (slope > 0 && is_viable(time_remaining, boost_accel, gravity, me, r.ball_intercept))
+        if (slope > 0 && is_viable(time_remaining, ceil(best_shot_value - 92.75) * 2, boost_accel, gravity, me, r.ball_intercept))
             r.found = 1;
     }
 
     return r;
 };
 
-static PyObject *method_parse_slice_for_jump_shot_with_target(PyObject *self, PyObject *args) {
+static PyObject *method_parse_slice_for_jump_shot_with_target(PyObject *self, PyObject *args)
+{
     int car_boost;
     double time_remaining, best_shot_value, cap_;
     Vector ball_location, car_location, car_forward, left_target, right_target;
 
-    if (!PyArg_ParseTuple(args, "d(ddd)(ddd)(ddd)i(ddd)(ddd)d", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
+    if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)i(ddd)(ddd)d", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &left_target.x, &left_target.y, &left_target.z, &right_target.x, &right_target.y, &right_target.z, &cap_))
         return NULL;
 
     struct jump_shot data_struct = parse_slice_for_jump_shot_with_target(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, left_target, right_target, cap_);
 
-    return Py_BuildValue("{s:i,s:(ddd),s:i}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z, "direction", data_struct.direction);
+    return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z);
 };
 
-static PyObject *method_parse_slice_for_jump_shot(PyObject *self, PyObject *args) {
+static PyObject *method_parse_slice_for_jump_shot(PyObject *self, PyObject *args)
+{
     int car_boost;
     double time_remaining, best_shot_value, cap_;
     Vector ball_location, car_location, car_forward;
 
-    if (!PyArg_ParseTuple(args, "d(ddd)(ddd)(ddd)id", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &cap_))
+    if (!PyArg_ParseTuple(args, "dd(ddd)(ddd)(ddd)id", &time_remaining, &best_shot_value, &ball_location.x, &ball_location.y, &ball_location.z, &car_location.x, &car_location.y, &car_location.z, &car_forward.x, &car_forward.y, &car_forward.z, &car_boost, &cap_))
         return NULL;
 
     struct jump_shot data_struct = parse_slice_for_jump_shot(time_remaining, best_shot_value, ball_location, car_location, car_forward, car_boost, cap_);
 
-    return Py_BuildValue("{s:i,s:(ddd),s:i}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z, "direction", data_struct.direction);
+    return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "best_shot_vector", data_struct.best_shot_vector.x, data_struct.best_shot_vector.y, data_struct.best_shot_vector.z);
 };
 
-static PyObject *method_parse_slice_for_aerial_shot_with_target(PyObject *self, PyObject *args) {
+static PyObject *method_parse_slice_for_aerial_shot_with_target(PyObject *self, PyObject *args)
+{
     struct car me;
     double time_remaining, best_shot_value, boost_accel, cap_;
     Vector gravity, ball_location, left_target, right_target;
@@ -384,7 +398,8 @@ static PyObject *method_parse_slice_for_aerial_shot_with_target(PyObject *self,
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "ball_intercept", data_struct.ball_intercept.x, data_struct.ball_intercept.y, data_struct.ball_intercept.z);
 };
 
-static PyObject *method_parse_slice_for_aerial_shot(PyObject *self, PyObject *args) {
+static PyObject *method_parse_slice_for_aerial_shot(PyObject *self, PyObject *args)
+{
     struct car me;
     double time_remaining, best_shot_value, boost_accel, cap_;
     Vector gravity, ball_location;
@@ -397,22 +412,21 @@ static PyObject *method_parse_slice_for_aerial_shot(PyObject *self, PyObject *ar
     return Py_BuildValue("{s:i,s:(ddd)}", "found", data_struct.found, "ball_intercept", data_struct.ball_intercept.x, data_struct.ball_intercept.y, data_struct.ball_intercept.z);
 };
 
-static PyMethodDef methods[] ={
-    { "parse_slice_for_jump_shot_with_target", method_parse_slice_for_jump_shot_with_target, METH_VARARGS, "Parse slice for a jump shot with a target" },
-    { "parse_slice_for_jump_shot", method_parse_slice_for_jump_shot, METH_VARARGS, "Parse slice for a jump shot" },
-    { "parse_slice_for_aerial_shot_with_target", method_parse_slice_for_aerial_shot_with_target, METH_VARARGS, "Parse slice for an aerial shot with a target" },
-    { "parse_slice_for_aerial_shot", method_parse_slice_for_aerial_shot, METH_VARARGS, "Parse slice for an aerial shot" },
-    { NULL, NULL, 0, NULL }
-};
+static PyMethodDef methods[] = {
+    {"parse_slice_for_jump_shot_with_target", method_parse_slice_for_jump_shot_with_target, METH_VARARGS, "Parse slice for a jump shot with a target"},
+    {"parse_slice_for_jump_shot", method_parse_slice_for_jump_shot, METH_VARARGS, "Parse slice for a jump shot"},
+    {"parse_slice_for_aerial_shot_with_target", method_parse_slice_for_aerial_shot_with_target, METH_VARARGS, "Parse slice for an aerial shot with a target"},
+    {"parse_slice_for_aerial_shot", method_parse_slice_for_aerial_shot, METH_VARARGS, "Parse slice for an aerial shot"},
+    {NULL, NULL, 0, NULL}};
 
-static struct PyModuleDef module ={
+static struct PyModuleDef module = {
     PyModuleDef_HEAD_INIT,
     "virxrlcu",
     "C Library for VirxERLU",
     -1,
-    methods
-};
+    methods};
 
-PyMODINIT_FUNC PyInit_virxrlcu(void) {
+PyMODINIT_FUNC PyInit_virxrlcu(void)
+{
     return PyModule_Create(&module);
 };
\ No newline at end of file
